@@ -37,17 +37,13 @@ MainWindow::MainWindow(QWidget *parent)
 {
 
 
+
+
 metaInformationResolver = new Phonon::MediaObject(this);
 
     ui.setupUi(this);
 
 
-    scene = new QGraphicsScene;
-    ui.graphicsView->setScene(scene);
-    QBrush br(Qt::NoBrush);
-
-scene->setForegroundBrush(br);
-    scene->setBackgroundBrush(br);
 
 moo = new Phonon::MediaObject;;
 device = new Phonon::AudioOutput;
@@ -288,6 +284,22 @@ bool MainWindow::eventFilter(QObject *obj, QEvent *event)
         return true;
         break;
 
+        case Qt::Key_H:
+        kbdhelp();
+        return true;
+        break;
+
+        case Qt::Key_Q:
+        if (keyEvent->modifiers()&&Qt::ControlModifier==keyEvent->modifiers()){
+            qApp->exit();
+            return true;}
+        break;
+
+        case Qt::Key_M:
+        device->setMuted(!device->isMuted());
+        return true;
+        break;
+
         default: return QObject::eventFilter(obj, event); break;
 
 
@@ -343,7 +355,8 @@ QScrollArea tu(&dg);
 tu.setWidget(&t);
 
 // fg->addWidget(&t);
- t.setTextInteractionFlags(Qt::TextBrowserInteraction|Qt::TextSelectableByMouse);
+// t.setTextInteractionFlags(Qt::TextBrowserInteraction|Qt::TextSelectableByMouse);
+
 dg.exec();
 }
 
@@ -406,6 +419,8 @@ scrobler=new last(tyu.at(4),tyu.at(5));
                 scrobler=new last("","");
 
             }
+            if (tyu.count()>6)iload=QString(tyu.at(6)).toLong();else iload=0;
+
 
 file.close();
 #ifdef Q_WS_MAEMO_5
@@ -445,16 +460,47 @@ void MainWindow::about(){
     QLabel *text=new QLabel("<center><h3>TPlayer</h3></center><br />This program is distributed under terms of GNU GPL v3<br />" \
                             "Source code can be founded at <a href=\"http://googlecode.com/p/tplayer\">http://googlecode.com/p/tplayer</a><br /><br />" \
                             "Lead developer: <bold>Bonapart</bold><br />" \
-                            "Web-developer : <bold>[VS]</bold>",dwidget);
-    QPushButton *aqt=new QPushButton("AboutQt",dwidget);
+                            "Web-developer : <bold>[vs]</bold>",dwidget);
+    QPushButton *aqt=new QPushButton("About Qt",dwidget);
+    QPushButton *kbd=new QPushButton("Keyboard help",dwidget);
     QVBoxLayout *mlay=new QVBoxLayout(dwidget);
+    QHBoxLayout *dlay=new QHBoxLayout();
     connect(aqt,SIGNAL(clicked()),qApp,SLOT(aboutQt()));
+    connect(kbd,SIGNAL(clicked()),this,SLOT(kbdhelp()));
+
     mlay->addWidget(text);
-    mlay->addWidget(aqt);
+    mlay->addLayout(dlay);
+    dlay->addWidget(aqt);
+    dlay->addWidget(kbd);
 
 
 dwidget->exec();
 }
+void MainWindow::kbdhelp(){
+    QDialog *dg=new QDialog(0);
+    QString text= QString("left key - previous song<br />" \
+                          "right key - next song<br />" \
+                          "space key - play\\pause<br />" \
+                          "m key - mute\\unmute<br />" \
+                          "z - song tab<br />" \
+                          "x - playlist tab<br />" \
+                          "c - lyrics tab<br />" \
+                          "v - biography tab<br />" \
+                          "b - equalizer tab<br />" \
+                          "h - this message<br />" \
+                          "ctrl+q - quit");
+
+
+    QScrollArea tu(dg);
+     QHBoxLayout *fg=new QHBoxLayout(dg);
+     fg->addWidget(&tu);
+
+     QLabel t(QString(text),&tu);
+    tu.setWidget(&t);
+
+
+dg->exec();
+}
 
 MainWindow::~MainWindow()
 {
@@ -603,17 +649,12 @@ void MainWindow::currentItemChanged ( QListWidgetItem * current ){
 
 
 void MainWindow::changePlay( Phonon::State newstate, Phonon::State oldstate ) {
-
-    if (newstate==Phonon::PlayingState/*&&oldstate!=Phonon::PausedState*/){
+    ui.label->setText(list.value(ui.listWidget->currentRow()).at(2)+" - "+list.value(ui.listWidget->currentRow()).at(1));
+    this->setWindowTitle(list.value(ui.listWidget->currentRow()).at(2)+" - "+list.value(ui.listWidget->currentRow()).at(1));
+    if (newstate==Phonon::PlayingState&&oldstate!=Phonon::PausedState){
 
 scrobler->now(list.value(ui.listWidget->currentRow()),moo->totalTime());
 
-
-    }
-
-  //  if (newstate==Phonon::PlayingState|| newstate==Phonon::BufferingState ){
-    ui.label->setText(list.value(ui.listWidget->currentRow()).at(2)+" - "+list.value(ui.listWidget->currentRow()).at(1));
-    this->setWindowTitle(list.value(ui.listWidget->currentRow()).at(2)+" - "+list.value(ui.listWidget->currentRow()).at(1));
 #ifdef Q_WS_MAEMO_5
     if (!this->isActiveWindow()){
    QMaemo5InformationBox *box=new QMaemo5InformationBox();
@@ -623,37 +664,47 @@ box->setTimeout(3000);
 connect(box,SIGNAL(clicked()),this,SLOT(setFocus()));
 box->exec();}
 #endif
+ }
+    /*
+     iload - loading state variable
+     0- no load
+     1- just bios
+     2- bios+lyrics
+     3- bios-lyrics-images
 
 
+     */
+
     QString apath=QString(list.value(ui.listWidget->currentRow()).at(2)).toLower();
     apath.replace("/","");
     QString bpath=QString(apath+" - "+list.value(ui.listWidget->currentRow()).at(4)).toLower();
     bpath.replace("/","");
 
     QString cpath="/home/user/.covers/";
-    scene->clear();
+
+    QString dpath=QString(list.value(ui.listWidget->currentRow()).at(1)).toLower();
 
     if (QFileInfo(cpath+bpath+".jpg").exists()){
-
         QPixmap *t=new QPixmap(cpath+bpath+".jpg");
-
-         scene->addPixmap(t->scaled(ui.graphicsView->width(),ui.graphicsView->height(),Qt::KeepAspectRatio,Qt::FastTransformation));
-
+                ui.image->setPixmap(t->scaled(400,300,Qt::KeepAspectRatio,Qt::FastTransformation));
     }else{
          if (QFileInfo(cpath+apath+".jpg").exists()){
-
             QPixmap *t=new QPixmap(cpath+apath+".jpg");
-             //t= t->scaled(ui.graphicsView->width(),ui.graphicsView->height(),Qt::KeepAspectRatio,Qt::FastTransformation);
-             scene->addPixmap(t->scaled(ui.graphicsView->width(),ui.graphicsView->height(),Qt::KeepAspectRatio,Qt::FastTransformation));
-
-
-         }
+            ui.image->setPixmap(t->scaled(400,300,Qt::KeepAspectRatio,Qt::FastTransformation));
 
+        }else{
+            ui.image->setPixmap(QPixmap());
+            if (iload>2){
+                dart();
+            }
+        }
 }
-
+ui.textEdit->setText("");
+ui.textEdit_2->setText("");
 
     QFile file("/home/user/.bios/"+apath+".html");
     if (!file.exists()){
+        if (iload>0){
          QUrl url("http://team16.ru/grab.php?bio="+apath);
 
          QNetworkAccessManager *manager = new QNetworkAccessManager(this);
@@ -663,16 +714,37 @@ box->exec();}
 
 
           manager->get(QNetworkRequest(url));
+      }
       }else{
           if (!file.open(QIODevice::ReadOnly|QFile::Text))  return ;
 
            QTextCodec *codec = QTextCodec::codecForName("UTF-8");
 
       ui.textEdit->setHtml( codec->toUnicode(file.readAll()));
-    //  ui.textEdit->setHtml(file.readAll());
       file.close();
       }
-  //}
+
+      QFile file2("/home/user/.lyrics/"+apath+"-"+dpath+".html");
+      if (!file2.exists()){
+          if (iload>1){
+           QUrl url("http://team16.ru/grab.php?band="+apath+"&lyrics="+dpath);
+
+           QNetworkAccessManager *manager = new QNetworkAccessManager(this);
+
+            connect(manager, SIGNAL(finished(QNetworkReply*)),
+                    this, SLOT(replyFinished3(QNetworkReply*)));
+
+
+            manager->get(QNetworkRequest(url));
+        }
+        }else{
+            if (!file2.open(QIODevice::ReadOnly|QFile::Text))  return ;
+
+             QTextCodec *codec = QTextCodec::codecForName("UTF-8");
+
+        ui.textEdit_2->setHtml( codec->toUnicode(file2.readAll()));
+        file2.close();
+        }
 
 }
 
@@ -699,6 +771,29 @@ void MainWindow::replyFinished(QNetworkReply*reply){
 
 }
 
+void MainWindow::replyFinished3(QNetworkReply*reply){
+
+    QDir g;
+
+    g.mkdir("/home/user/.lyrics");
+    QFile file("/home/user/.lyrics/"+reply->url().queryItems().at(0).second+"-"+reply->url().queryItems().at(1).second+".html");
+        if (!file.open(QIODevice::WriteOnly))  return ;
+
+  QString jk;
+  QTextCodec *codec = QTextCodec::codecForName("UTF-8");
+
+  jk=codec->toUnicode(reply->readAll());
+  QTextStream out(&file);
+        out <<jk;
+        file.close();
+
+    if (!file.open(QIODevice::ReadOnly|QFile::Text))  return ;
+    QTextCodec *codec2 = QTextCodec::codecForName("UTF-8");
+    ui.textEdit_2->setHtml( codec2->toUnicode(file.readAll()));
+    file.close();
+
+}
+
 
 void MainWindow::dart(){
     QString apath=QString(list.value(ui.listWidget->currentRow()).at(2)).toLower().replace("/","");
@@ -761,18 +856,18 @@ fl=reply->url().queryItems().at(0).second;
     QString apath=QString(list.value(ui.listWidget->currentRow()).at(2)).toLower().replace("/","");
     QString bpath=QString(apath+" - "+list.value(ui.listWidget->currentRow()).at(4)).toLower().replace("/","");
 
-scene->clear();
+
     QString cpath="/home/user/.covers/";
     if (QFileInfo(cpath+bpath+".jpg").exists()){
 
         QPixmap *t=new QPixmap(cpath+bpath+".jpg");
-        scene->addPixmap(t->scaled(ui.graphicsView->width(),ui.graphicsView->height(),Qt::KeepAspectRatio,Qt::FastTransformation));
+        ui.image->setPixmap(t->scaled(400,300,Qt::KeepAspectRatio,Qt::FastTransformation));
 
     }else{
          if (QFileInfo(cpath+apath+".jpg").exists()){
 
             QPixmap *t=new QPixmap(cpath+apath+".jpg");
-           scene->addPixmap(t->scaled(ui.graphicsView->width(),ui.graphicsView->height(),Qt::KeepAspectRatio,Qt::FastTransformation));
+             ui.image->setPixmap(t->scaled(400,300,Qt::KeepAspectRatio,Qt::FastTransformation));
 
          }
 }
