@@ -33,9 +33,10 @@ public:
     options *opt;
     lmaster *lmast;
     int rotate;
+    int iload;
     last *scrobler;
     Phonon::VideoWidget *vwidget;
-    QGraphicsScene * scene ;
+
     QSqlDatabase db;
     QString currentQuery;
     QMenu *tmenu;
@@ -80,7 +81,9 @@ public slots:
     void dart();
     void dart2();
     void replyFinished2(QNetworkReply*);
-void orientationChanged();
+    void replyFinished3(QNetworkReply*);
+    void kbdhelp();
+    void orientationChanged();
 protected:
   void keyPressEvent(QKeyEvent* event);
   bool eventFilter(QObject *obj, QEvent *event);
