@@ -22,6 +22,7 @@ QFile file("/home/user/.tplayerrc");
 ui.lineEdit->setText(tyu.at(3));
 ui.lineEdit_2->setText(tyu.at(4));
 ui.lineEdit_3->setText(tyu.at(5));
+ui.comboBox_2->setCurrentIndex(tyu.at(6).toLong());
 file.close();
 }
 
@@ -40,12 +41,13 @@ void options::save(){
             return;
 
         QTextStream out(&file);
-        out <<QString("%1\n%2\n%3\n%4\n%5\n%6\n").arg(ui.comboBox->currentIndex())
+        out <<QString("%1\n%2\n%3\n%4\n%5\n%6\n%7\n").arg(ui.comboBox->currentIndex())
                 .arg(ui.fontComboBox->currentFont().toString())
                 .arg(ui.spinBox->value())
                 .arg(ui.lineEdit->text())
                 .arg(ui.lineEdit_2->text())
-                .arg(ui.lineEdit_3->text());
+                .arg(ui.lineEdit_3->text())
+                .arg(ui.comboBox_2->currentIndex());
         file.close();
         this->accept();
         this->close();
